@@ -5,4 +5,4 @@ import datetime
 class Calc(object):
     @staticmethod
     def current_time():
-        return str(datetime.datetime.now()).split('.')[0]
+        return str(datetime.datetime.now()).split(".")[0]
